/*
 * Copyright (c) 1994 Cygnus Support.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms are permitted
 * provided that the above copyright notice and this paragraph are
 * duplicated in all such forms and that any documentation,
 * and/or other materials related to such
 * distribution and use acknowledge that the software was developed
 * at Cygnus Support, Inc.  Cygnus Support, Inc. may not be used to
 * endorse or promote products derived from this software without
 * specific prior written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */
#include "test.h"
 one_line_type exp_vec[] = {
{64, 0,123,__LINE__, 0x3fd346c4, 0x167a12df, 0xbff33333, 0x33333333},	/* 0.301194=f(-1.2)*/
{63, 0,123,__LINE__, 0x3fd3785c, 0x76fa8377, 0xbff30a3d, 0x70a3d70a},	/* 0.304221=f(-1.19)*/
{64, 0,123,__LINE__, 0x3fd3aa74, 0x7143124b, 0xbff2e147, 0xae147ae1},	/* 0.307279=f(-1.18)*/
{63, 0,123,__LINE__, 0x3fd3dd0d, 0x4d9faafc, 0xbff2b851, 0xeb851eb8},	/* 0.310367=f(-1.17)*/
{64, 0,123,__LINE__, 0x3fd41028, 0x57a8e0f5, 0xbff28f5c, 0x28f5c28f},	/* 0.313486=f(-1.16)*/
{63, 0,123,__LINE__, 0x3fd443c6, 0xde4c6c98, 0xbff26666, 0x66666666},	/* 0.316637=f(-1.15)*/
{63, 0,123,__LINE__, 0x3fd477ea, 0x33d5be3c, 0xbff23d70, 0xa3d70a3d},	/* 0.319819=f(-1.14)*/
{64, 0,123,__LINE__, 0x3fd4ac93, 0xadf6a741, 0xbff2147a, 0xe147ae14},	/* 0.323033=f(-1.13)*/
{63, 0,123,__LINE__, 0x3fd4e1c4, 0xa5d0196b, 0xbff1eb85, 0x1eb851eb},	/* 0.32628=f(-1.12)*/
{63, 0,123,__LINE__, 0x3fd5177e, 0x77fafcb6, 0xbff1c28f, 0x5c28f5c2},	/* 0.329559=f(-1.11)*/
{64, 0,123,__LINE__, 0x3fd54dc2, 0x84911bf2, 0xbff19999, 0x99999999},	/* 0.332871=f(-1.1)*/
{63, 0,123,__LINE__, 0x3fd58492, 0x2f36284d, 0xbff170a3, 0xd70a3d70},	/* 0.336216=f(-1.09)*/
{62, 0,123,__LINE__, 0x3fd5bbee, 0xdf20d410, 0xbff147ae, 0x147ae147},	/* 0.339596=f(-1.08)*/
{64, 0,123,__LINE__, 0x3fd5f3d9, 0xff2404c8, 0xbff11eb8, 0x51eb851e},	/* 0.343009=f(-1.07)*/
{63, 0,123,__LINE__, 0x3fd62c54, 0xfdb81d19, 0xbff0f5c2, 0x8f5c28f5},	/* 0.346456=f(-1.06)*/
{64, 0,123,__LINE__, 0x3fd66561, 0x4d045e77, 0xbff0cccc, 0xcccccccc},	/* 0.349938=f(-1.05)*/
{63, 0,123,__LINE__, 0x3fd69f00, 0x62e862ff, 0xbff0a3d7, 0x0a3d70a3},	/* 0.353455=f(-1.04)*/
{64, 0,123,__LINE__, 0x3fd6d933, 0xb905afb7, 0xbff07ae1, 0x47ae147a},	/* 0.357007=f(-1.03)*/
{63, 0,123,__LINE__, 0x3fd713fc, 0xccc95f68, 0xbff051eb, 0x851eb851},	/* 0.360595=f(-1.02)*/
{64, 0,123,__LINE__, 0x3fd74f5d, 0x1f75e65c, 0xbff028f5, 0xc28f5c28},	/* 0.364219=f(-1.01)*/
{63, 0,123,__LINE__, 0x3fd78b56, 0x362cef39, 0xbfefffff, 0xfffffffe},	/* 0.367879=f(-1)*/
{64, 0,123,__LINE__, 0x3fd7c7e9, 0x99f9513d, 0xbfefae14, 0x7ae147ac},	/* 0.371577=f(-0.99)*/
{63, 0,123,__LINE__, 0x3fd80518, 0xd7d9201b, 0xbfef5c28, 0xf5c28f5a},	/* 0.375311=f(-0.98)*/
{63, 0,123,__LINE__, 0x3fd842e5, 0x80c7d5bc, 0xbfef0a3d, 0x70a3d708},	/* 0.379083=f(-0.97)*/
{63, 0,123,__LINE__, 0x3fd88151, 0x29c89623, 0xbfeeb851, 0xeb851eb6},	/* 0.382893=f(-0.96)*/
{64, 0,123,__LINE__, 0x3fd8c05d, 0x6bf08dc1, 0xbfee6666, 0x66666664},	/* 0.386741=f(-0.95)*/
{63, 0,123,__LINE__, 0x3fd9000b, 0xe4716a6e, 0xbfee147a, 0xe147ae12},	/* 0.390628=f(-0.94)*/
{64, 0,123,__LINE__, 0x3fd9405e, 0x34a3ef58, 0xbfedc28f, 0x5c28f5c0},	/* 0.394554=f(-0.93)*/
{64, 0,123,__LINE__, 0x3fd98156, 0x0212a428, 0xbfed70a3, 0xd70a3d6e},	/* 0.398519=f(-0.92)*/
{64, 0,123,__LINE__, 0x3fd9c2f4, 0xf6849fa6, 0xbfed1eb8, 0x51eb851c},	/* 0.402524=f(-0.91)*/
{62, 0,123,__LINE__, 0x3fda053c, 0xc0086e20, 0xbfeccccc, 0xccccccca},	/* 0.40657=f(-0.9)*/
{62, 0,123,__LINE__, 0x3fda482f, 0x10ff13d9, 0xbfec7ae1, 0x47ae1478},	/* 0.410656=f(-0.89)*/
{63, 0,123,__LINE__, 0x3fda8bcd, 0xa0272bcf, 0xbfec28f5, 0xc28f5c26},	/* 0.414783=f(-0.88)*/
{64, 0,123,__LINE__, 0x3fdad01a, 0x28a8231e, 0xbfebd70a, 0x3d70a3d4},	/* 0.418952=f(-0.87)*/
{63, 0,123,__LINE__, 0x3fdb1516, 0x6a1d9146, 0xbfeb851e, 0xb851eb82},	/* 0.423162=f(-0.86)*/
{63, 0,123,__LINE__, 0x3fdb5ac4, 0x28a2ada0, 0xbfeb3333, 0x33333330},	/* 0.427415=f(-0.85)*/
{62, 0,123,__LINE__, 0x3fdba125, 0x2cdde257, 0xbfeae147, 0xae147ade},	/* 0.431711=f(-0.84)*/
{62, 0,123,__LINE__, 0x3fdbe83b, 0x440c7d1d, 0xbfea8f5c, 0x28f5c28c},	/* 0.436049=f(-0.83)*/
{63, 0,123,__LINE__, 0x3fdc3008, 0x400e7df8, 0xbfea3d70, 0xa3d70a3a},	/* 0.440432=f(-0.82)*/
{62, 0,123,__LINE__, 0x3fdc788d, 0xf7728478, 0xbfe9eb85, 0x1eb851e8},	/* 0.444858=f(-0.81)*/
{63, 0,123,__LINE__, 0x3fdcc1ce, 0x4581db8c, 0xbfe99999, 0x99999996},	/* 0.449329=f(-0.8)*/
{64, 0,123,__LINE__, 0x3fdd0bcb, 0x0a4ca466, 0xbfe947ae, 0x147ae144},	/* 0.453845=f(-0.79)*/
{64, 0,123,__LINE__, 0x3fdd5686, 0x2ab620a4, 0xbfe8f5c2, 0x8f5c28f2},	/* 0.458406=f(-0.78)*/
{64, 0,123,__LINE__, 0x3fdda201, 0x90811c17, 0xbfe8a3d7, 0x0a3d70a0},	/* 0.463013=f(-0.77)*/
{62, 0,123,__LINE__, 0x3fddee3f, 0x2a5c767e, 0xbfe851eb, 0x851eb84e},	/* 0.467666=f(-0.76)*/
{63, 0,123,__LINE__, 0x3fde3b40, 0xebefcd82, 0xbfe7ffff, 0xfffffffc},	/* 0.472367=f(-0.75)*/
{64, 0,123,__LINE__, 0x3fde8908, 0xcde84747, 0xbfe7ae14, 0x7ae147aa},	/* 0.477114=f(-0.74)*/
{63, 0,123,__LINE__, 0x3fded798, 0xce057de3, 0xbfe75c28, 0xf5c28f58},	/* 0.481909=f(-0.73)*/
{64, 0,123,__LINE__, 0x3fdf26f2, 0xef268c17, 0xbfe70a3d, 0x70a3d706},	/* 0.486752=f(-0.72)*/
{62, 0,123,__LINE__, 0x3fdf7719, 0x39573b98, 0xbfe6b851, 0xeb851eb4},	/* 0.491644=f(-0.71)*/
{63, 0,123,__LINE__, 0x3fdfc80d, 0xb9dd5546, 0xbfe66666, 0x66666662},	/* 0.496585=f(-0.7)*/
{64, 0,123,__LINE__, 0x3fe00ce9, 0x41a309ce, 0xbfe6147a, 0xe147ae10},	/* 0.501576=f(-0.69)*/
{63, 0,123,__LINE__, 0x3fe03634, 0xd6b9dbe0, 0xbfe5c28f, 0x5c28f5be},	/* 0.506617=f(-0.68)*/
{64, 0,123,__LINE__, 0x3fe05fea, 0xaad5a0c1, 0xbfe570a3, 0xd70a3d6c},	/* 0.511709=f(-0.67)*/
{63, 0,123,__LINE__, 0x3fe08a0b, 0xcf512553, 0xbfe51eb8, 0x51eb851a},	/* 0.516851=f(-0.66)*/
{63, 0,123,__LINE__, 0x3fe0b499, 0x584682ed, 0xbfe4cccc, 0xccccccc8},	/* 0.522046=f(-0.65)*/
{63, 0,123,__LINE__, 0x3fe0df94, 0x5c9630d1, 0xbfe47ae1, 0x47ae1476},	/* 0.527292=f(-0.64)*/
{63, 0,123,__LINE__, 0x3fe10afd, 0xf5ee27da, 0xbfe428f5, 0xc28f5c24},	/* 0.532592=f(-0.63)*/
{64, 0,123,__LINE__, 0x3fe136d7, 0x40d11881, 0xbfe3d70a, 0x3d70a3d2},	/* 0.537944=f(-0.62)*/
{64, 0,123,__LINE__, 0x3fe16321, 0x5c9db374, 0xbfe3851e, 0xb851eb80},	/* 0.543351=f(-0.61)*/
{64, 0,123,__LINE__, 0x3fe18fdd, 0x6b9604e6, 0xbfe33333, 0x3333332e},	/* 0.548812=f(-0.6)*/
{63, 0,123,__LINE__, 0x3fe1bd0c, 0x92e6e2d4, 0xbfe2e147, 0xae147adc},	/* 0.554327=f(-0.59)*/
{63, 0,123,__LINE__, 0x3fe1eaaf, 0xfaaf6e5f, 0xbfe28f5c, 0x28f5c28a},	/* 0.559898=f(-0.58)*/
{64, 0,123,__LINE__, 0x3fe218c8, 0xce08a87a, 0xbfe23d70, 0xa3d70a38},	/* 0.565525=f(-0.57)*/
{63, 0,123,__LINE__, 0x3fe24758, 0x3b0d1a1c, 0xbfe1eb85, 0x1eb851e6},	/* 0.571209=f(-0.56)*/
{64, 0,123,__LINE__, 0x3fe2765f, 0x72e09020, 0xbfe19999, 0x99999994},	/* 0.57695=f(-0.55)*/
{63, 0,123,__LINE__, 0x3fe2a5df, 0xa9b7eb0b, 0xbfe147ae, 0x147ae142},	/* 0.582748=f(-0.54)*/
{63, 0,123,__LINE__, 0x3fe2d5da, 0x16e102f1, 0xbfe0f5c2, 0x8f5c28f0},	/* 0.588605=f(-0.53)*/
{64, 0,123,__LINE__, 0x3fe3064f, 0xf4ca9fa0, 0xbfe0a3d7, 0x0a3d709e},	/* 0.594521=f(-0.52)*/
{64, 0,123,__LINE__, 0x3fe33742, 0x810c8552, 0xbfe051eb, 0x851eb84c},	/* 0.600496=f(-0.51)*/
{64, 0,123,__LINE__, 0x3fe368b2, 0xfc6f960e, 0xbfdfffff, 0xfffffff4},	/* 0.606531=f(-0.5)*/
{63, 0,123,__LINE__, 0x3fe39aa2, 0xaaf607f9, 0xbfdf5c28, 0xf5c28f50},	/* 0.612626=f(-0.49)*/
{64, 0,123,__LINE__, 0x3fe3cd12, 0xd3e3b0cb, 0xbfdeb851, 0xeb851eac},	/* 0.618783=f(-0.48)*/
{64, 0,123,__LINE__, 0x3fe40004, 0xc1c66690, 0xbfde147a, 0xe147ae08},	/* 0.625002=f(-0.47)*/
{64, 0,123,__LINE__, 0x3fe43379, 0xc27e7604, 0xbfdd70a3, 0xd70a3d64},	/* 0.631284=f(-0.46)*/
{64, 0,123,__LINE__, 0x3fe46773, 0x27472ead, 0xbfdccccc, 0xccccccc0},	/* 0.637628=f(-0.45)*/
{64, 0,123,__LINE__, 0x3fe49bf2, 0x44bf84f3, 0xbfdc28f5, 0xc28f5c1c},	/* 0.644036=f(-0.44)*/
{63, 0,123,__LINE__, 0x3fe4d0f8, 0x72f2ca72, 0xbfdb851e, 0xb851eb78},	/* 0.650509=f(-0.43)*/
{64, 0,123,__LINE__, 0x3fe50687, 0x0d617cbb, 0xbfdae147, 0xae147ad4},	/* 0.657047=f(-0.42)*/
{63, 0,123,__LINE__, 0x3fe53c9f, 0x730a2ab5, 0xbfda3d70, 0xa3d70a30},	/* 0.66365=f(-0.41)*/
{64, 0,123,__LINE__, 0x3fe57343, 0x067270f2, 0xbfd99999, 0x9999998c},	/* 0.67032=f(-0.4)*/
{64, 0,123,__LINE__, 0x3fe5aa73, 0x2db00d13, 0xbfd8f5c2, 0x8f5c28e8},	/* 0.677057=f(-0.39)*/
{62, 0,123,__LINE__, 0x3fe5e231, 0x5272088d, 0xbfd851eb, 0x851eb844},	/* 0.683861=f(-0.38)*/
{62, 0,123,__LINE__, 0x3fe61a7e, 0xe209fb04, 0xbfd7ae14, 0x7ae147a0},	/* 0.690734=f(-0.37)*/
{63, 0,123,__LINE__, 0x3fe6535d, 0x4d756475, 0xbfd70a3d, 0x70a3d6fc},	/* 0.697676=f(-0.36)*/
{63, 0,123,__LINE__, 0x3fe68cce, 0x09671f76, 0xbfd66666, 0x66666658},	/* 0.704688=f(-0.35)*/
{64, 0,123,__LINE__, 0x3fe6c6d2, 0x8e50ebbb, 0xbfd5c28f, 0x5c28f5b4},	/* 0.71177=f(-0.34)*/
{63, 0,123,__LINE__, 0x3fe7016c, 0x586d112e, 0xbfd51eb8, 0x51eb8510},	/* 0.718924=f(-0.33)*/
{63, 0,123,__LINE__, 0x3fe73c9c, 0xe7c81bd3, 0xbfd47ae1, 0x47ae146c},	/* 0.726149=f(-0.32)*/
{63, 0,123,__LINE__, 0x3fe77865, 0xc04ab0b1, 0xbfd3d70a, 0x3d70a3c8},	/* 0.733447=f(-0.31)*/
{63, 0,123,__LINE__, 0x3fe7b4c8, 0x69c37c0b, 0xbfd33333, 0x33333324},	/* 0.740818=f(-0.3)*/
{63, 0,123,__LINE__, 0x3fe7f1c6, 0x6ff13926, 0xbfd28f5c, 0x28f5c280},	/* 0.748264=f(-0.29)*/
{62, 0,123,__LINE__, 0x3fe82f61, 0x628cd3df, 0xbfd1eb85, 0x1eb851dc},	/* 0.755784=f(-0.28)*/
{63, 0,123,__LINE__, 0x3fe86d9a, 0xd553a449, 0xbfd147ae, 0x147ae138},	/* 0.763379=f(-0.27)*/
{63, 0,123,__LINE__, 0x3fe8ac74, 0x6011c4ac, 0xbfd0a3d7, 0x0a3d7094},	/* 0.771052=f(-0.26)*/
{63, 0,123,__LINE__, 0x3fe8ebef, 0x9eac8211, 0xbfcfffff, 0xffffffe0},	/* 0.778801=f(-0.25)*/
{62, 0,123,__LINE__, 0x3fe92c0e, 0x312ce7af, 0xbfceb851, 0xeb851e98},	/* 0.786628=f(-0.24)*/
{64, 0,123,__LINE__, 0x3fe96cd1, 0xbbca6578, 0xbfcd70a3, 0xd70a3d50},	/* 0.794534=f(-0.23)*/
{62, 0,123,__LINE__, 0x3fe9ae3b, 0xe6f59210, 0xbfcc28f5, 0xc28f5c08},	/* 0.802519=f(-0.22)*/
{62, 0,123,__LINE__, 0x3fe9f04e, 0x5f630869, 0xbfcae147, 0xae147ac0},	/* 0.810584=f(-0.21)*/
{64, 0,123,__LINE__, 0x3fea330a, 0xd6166160, 0xbfc99999, 0x99999978},	/* 0.818731=f(-0.2)*/
{64, 0,123,__LINE__, 0x3fea7673, 0x006d498c, 0xbfc851eb, 0x851eb830},	/* 0.826959=f(-0.19)*/
{62, 0,123,__LINE__, 0x3feaba88, 0x982ab397, 0xbfc70a3d, 0x70a3d6e8},	/* 0.83527=f(-0.18)*/
{62, 0,123,__LINE__, 0x3feaff4d, 0x5b822766, 0xbfc5c28f, 0x5c28f5a0},	/* 0.843665=f(-0.17)*/
{62, 0,123,__LINE__, 0x3feb44c3, 0x0d232e57, 0xbfc47ae1, 0x47ae1458},	/* 0.852144=f(-0.16)*/
{64, 0,123,__LINE__, 0x3feb8aeb, 0x7444dce8, 0xbfc33333, 0x33333310},	/* 0.860708=f(-0.15)*/
{62, 0,123,__LINE__, 0x3febd1c8, 0x5cb17a03, 0xbfc1eb85, 0x1eb851c8},	/* 0.869358=f(-0.14)*/
{63, 0,123,__LINE__, 0x3fec195b, 0x96d24456, 0xbfc0a3d7, 0x0a3d7080},	/* 0.878095=f(-0.13)*/
{63, 0,123,__LINE__, 0x3fec61a6, 0xf7bb55e0, 0xbfbeb851, 0xeb851e71},	/* 0.88692=f(-0.12)*/
{64, 0,123,__LINE__, 0x3fecaaac, 0x5937a626, 0xbfbc28f5, 0xc28f5be2},	/* 0.895834=f(-0.11)*/
{64, 0,123,__LINE__, 0x3fecf46d, 0x99d52b42, 0xbfb99999, 0x99999953},	/* 0.904837=f(-0.1)*/
{64, 0,123,__LINE__, 0x3fed3eec, 0x9cf11a2e, 0xbfb70a3d, 0x70a3d6c4},	/* 0.913931=f(-0.09)*/
{64, 0,123,__LINE__, 0x3fed8a2b, 0x4ac4468d, 0xbfb47ae1, 0x47ae1435},	/* 0.923116=f(-0.08)*/
{63, 0,123,__LINE__, 0x3fedd62b, 0x906fa254, 0xbfb1eb85, 0x1eb851a6},	/* 0.932394=f(-0.07)*/
{62, 0,123,__LINE__, 0x3fee22ef, 0x6008dd8f, 0xbfaeb851, 0xeb851e2d},	/* 0.941765=f(-0.06)*/
{63, 0,123,__LINE__, 0x3fee7078, 0xb0a726ae, 0xbfa99999, 0x9999990e},	/* 0.951229=f(-0.05)*/
{64, 0,123,__LINE__, 0x3feebec9, 0x7e700b96, 0xbfa47ae1, 0x47ae13ef},	/* 0.960789=f(-0.04)*/
{64, 0,123,__LINE__, 0x3fef0de3, 0xcaa47bd8, 0xbf9eb851, 0xeb851da0},	/* 0.970446=f(-0.03)*/
{63, 0,123,__LINE__, 0x3fef5dc9, 0x9badec64, 0xbf947ae1, 0x47ae1362},	/* 0.980199=f(-0.02)*/
{64, 0,123,__LINE__, 0x3fefae7c, 0xfd2b9d06, 0xbf847ae1, 0x47ae1249},	/* 0.99005=f(-0.01)*/
{63, 0,123,__LINE__, 0x3ff00000, 0x00000004, 0x3cd19000, 0x00000000},	/* 1=f(9.74915e-16)*/
{64, 0,123,__LINE__, 0x3ff0292a, 0x5d2f222b, 0x3f847ae1, 0x47ae16ad},	/* 1.01005=f(0.01)*/
{63, 0,123,__LINE__, 0x3ff052be, 0xa3ec0137, 0x3f947ae1, 0x47ae1594},	/* 1.0202=f(0.02)*/
{63, 0,123,__LINE__, 0x3ff07cbd, 0xe4b58645, 0x3f9eb851, 0xeb851fd2},	/* 1.03045=f(0.03)*/
{64, 0,123,__LINE__, 0x3ff0a729, 0x32c7b12a, 0x3fa47ae1, 0x47ae1508},	/* 1.04081=f(0.04)*/
{64, 0,123,__LINE__, 0x3ff0d201, 0xa422a437, 0x3fa99999, 0x99999a27},	/* 1.05127=f(0.05)*/
{63, 0,123,__LINE__, 0x3ff0fd48, 0x5191c22d, 0x3faeb851, 0xeb851f46},	/* 1.06184=f(0.06)*/
{64, 0,123,__LINE__, 0x3ff128fe, 0x56b2de6e, 0x3fb1eb85, 0x1eb85232},	/* 1.07251=f(0.07)*/
{63, 0,123,__LINE__, 0x3ff15524, 0xd1fd7fc1, 0x3fb47ae1, 0x47ae14c1},	/* 1.08329=f(0.08)*/
{64, 0,123,__LINE__, 0x3ff181bc, 0xe4ca35b2, 0x3fb70a3d, 0x70a3d750},	/* 1.09417=f(0.09)*/
{63, 0,123,__LINE__, 0x3ff1aec7, 0xb35a00d8, 0x3fb99999, 0x999999df},	/* 1.10517=f(0.1)*/
{63, 0,123,__LINE__, 0x3ff1dc46, 0x64ddce32, 0x3fbc28f5, 0xc28f5c6e},	/* 1.11628=f(0.11)*/
{63, 0,123,__LINE__, 0x3ff20a3a, 0x237e05b1, 0x3fbeb851, 0xeb851efd},	/* 1.1275=f(0.12)*/
{64, 0,123,__LINE__, 0x3ff238a4, 0x1c622c44, 0x3fc0a3d7, 0x0a3d70c6},	/* 1.13883=f(0.13)*/
{63, 0,123,__LINE__, 0x3ff26785, 0x7fb89983, 0x3fc1eb85, 0x1eb8520e},	/* 1.15027=f(0.14)*/
{64, 0,123,__LINE__, 0x3ff296df, 0x80be4127, 0x3fc33333, 0x33333356},	/* 1.16183=f(0.15)*/
{64, 0,123,__LINE__, 0x3ff2c6b3, 0x55c6909c, 0x3fc47ae1, 0x47ae149e},	/* 1.17351=f(0.16)*/
{63, 0,123,__LINE__, 0x3ff2f702, 0x384360bd, 0x3fc5c28f, 0x5c28f5e6},	/* 1.1853=f(0.17)*/
{63, 0,123,__LINE__, 0x3ff327cd, 0x64ccfc0d, 0x3fc70a3d, 0x70a3d72e},	/* 1.19722=f(0.18)*/
{63, 0,123,__LINE__, 0x3ff35916, 0x1b2a3995, 0x3fc851eb, 0x851eb876},	/* 1.20925=f(0.19)*/
{62, 0,123,__LINE__, 0x3ff38add, 0x9e58ac92, 0x3fc99999, 0x999999be},	/* 1.2214=f(0.2)*/
{63, 0,123,__LINE__, 0x3ff3bd25, 0x3494e93f, 0x3fcae147, 0xae147b06},	/* 1.23368=f(0.21)*/
{63, 0,123,__LINE__, 0x3ff3efee, 0x2762dedc, 0x3fcc28f5, 0xc28f5c4e},	/* 1.24608=f(0.22)*/
{63, 0,123,__LINE__, 0x3ff42339, 0xc3964739, 0x3fcd70a3, 0xd70a3d96},	/* 1.2586=f(0.23)*/
{63, 0,123,__LINE__, 0x3ff45709, 0x595b2bf0, 0x3fceb851, 0xeb851ede},	/* 1.27125=f(0.24)*/
{63, 0,123,__LINE__, 0x3ff48b5e, 0x3c3e818d, 0x3fd00000, 0x00000013},	/* 1.28403=f(0.25)*/
{63, 0,123,__LINE__, 0x3ff4c039, 0xc336d8d9, 0x3fd0a3d7, 0x0a3d70b7},	/* 1.29693=f(0.26)*/
{64, 0,123,__LINE__, 0x3ff4f59d, 0x48ad2688, 0x3fd147ae, 0x147ae15b},	/* 1.30996=f(0.27)*/
{63, 0,123,__LINE__, 0x3ff52b8a, 0x2a85a172, 0x3fd1eb85, 0x1eb851ff},	/* 1.32313=f(0.28)*/
{64, 0,123,__LINE__, 0x3ff56201, 0xca28b7ab, 0x3fd28f5c, 0x28f5c2a3},	/* 1.33643=f(0.29)*/
{64, 0,123,__LINE__, 0x3ff59905, 0x8c8c1a9c, 0x3fd33333, 0x33333347},	/* 1.34986=f(0.3)*/
{62, 0,123,__LINE__, 0x3ff5d096, 0xda3be26b, 0x3fd3d70a, 0x3d70a3eb},	/* 1.36343=f(0.31)*/
{63, 0,123,__LINE__, 0x3ff608b7, 0x1f63c8db, 0x3fd47ae1, 0x47ae148f},	/* 1.37713=f(0.32)*/
{64, 0,123,__LINE__, 0x3ff64167, 0xcbd87bfc, 0x3fd51eb8, 0x51eb8533},	/* 1.39097=f(0.33)*/
{63, 0,123,__LINE__, 0x3ff67aaa, 0x532108c4, 0x3fd5c28f, 0x5c28f5d7},	/* 1.40495=f(0.34)*/
{63, 0,123,__LINE__, 0x3ff6b480, 0x2c805df4, 0x3fd66666, 0x6666667b},	/* 1.41907=f(0.35)*/
{64, 0,123,__LINE__, 0x3ff6eeea, 0xd2fee767, 0x3fd70a3d, 0x70a3d71f},	/* 1.43333=f(0.36)*/
{63, 0,123,__LINE__, 0x3ff729eb, 0xc5744224, 0x3fd7ae14, 0x7ae147c3},	/* 1.44773=f(0.37)*/
{64, 0,123,__LINE__, 0x3ff76584, 0x86910960, 0x3fd851eb, 0x851eb867},	/* 1.46228=f(0.38)*/
{63, 0,123,__LINE__, 0x3ff7a1b6, 0x9ce8bcb8, 0x3fd8f5c2, 0x8f5c290b},	/* 1.47698=f(0.39)*/
{63, 0,123,__LINE__, 0x3ff7de83, 0x92fbbfe8, 0x3fd99999, 0x999999af},	/* 1.49182=f(0.4)*/
{63, 0,123,__LINE__, 0x3ff81bec, 0xf7417434, 0x3fda3d70, 0xa3d70a53},	/* 1.50682=f(0.41)*/
{63, 0,123,__LINE__, 0x3ff859f4, 0x5c326bd4, 0x3fdae147, 0xae147af7},	/* 1.52196=f(0.42)*/
{63, 0,123,__LINE__, 0x3ff8989b, 0x5852b79c, 0x3fdb851e, 0xb851eb9b},	/* 1.53726=f(0.43)*/
{64, 0,123,__LINE__, 0x3ff8d7e3, 0x863c4f25, 0x3fdc28f5, 0xc28f5c3f},	/* 1.55271=f(0.44)*/
{64, 0,123,__LINE__, 0x3ff917ce, 0x84a993bd, 0x3fdccccc, 0xcccccce3},	/* 1.56831=f(0.45)*/
{64, 0,123,__LINE__, 0x3ff9585d, 0xf67fee66, 0x3fdd70a3, 0xd70a3d87},	/* 1.58407=f(0.46)*/
{64, 0,123,__LINE__, 0x3ff99993, 0x82da891e, 0x3fde147a, 0xe147ae2b},	/* 1.59999=f(0.47)*/
{62, 0,123,__LINE__, 0x3ff9db70, 0xd51523c9, 0x3fdeb851, 0xeb851ecf},	/* 1.61607=f(0.48)*/
{62, 0,123,__LINE__, 0x3ffa1df7, 0x9cd704ef, 0x3fdf5c28, 0xf5c28f73},	/* 1.63232=f(0.49)*/
{64, 0,123,__LINE__, 0x3ffa6129, 0x8e1e06a5, 0x3fe00000, 0x0000000b},	/* 1.64872=f(0.5)*/
{63, 0,123,__LINE__, 0x3ffaa508, 0x6149bfe7, 0x3fe051eb, 0x851eb85d},	/* 1.66529=f(0.51)*/
{64, 0,123,__LINE__, 0x3ffae995, 0xd326caa1, 0x3fe0a3d7, 0x0a3d70af},	/* 1.68203=f(0.52)*/
{62, 0,123,__LINE__, 0x3ffb2ed3, 0xa4fa26c3, 0x3fe0f5c2, 0x8f5c2901},	/* 1.69893=f(0.53)*/
{63, 0,123,__LINE__, 0x3ffb74c3, 0x9c8cba98, 0x3fe147ae, 0x147ae153},	/* 1.71601=f(0.54)*/
{64, 0,123,__LINE__, 0x3ffbbb67, 0x8436f0bf, 0x3fe19999, 0x999999a5},	/* 1.73325=f(0.55)*/
{64, 0,123,__LINE__, 0x3ffc02c1, 0x2aec73f9, 0x3fe1eb85, 0x1eb851f7},	/* 1.75067=f(0.56)*/
{62, 0,123,__LINE__, 0x3ffc4ad2, 0x6448093a, 0x3fe23d70, 0xa3d70a49},	/* 1.76827=f(0.57)*/
{64, 0,123,__LINE__, 0x3ffc939d, 0x08978822, 0x3fe28f5c, 0x28f5c29b},	/* 1.78604=f(0.58)*/
{63, 0,123,__LINE__, 0x3ffcdd22, 0xf4e7f25b, 0x3fe2e147, 0xae147aed},	/* 1.80399=f(0.59)*/
{63, 0,123,__LINE__, 0x3ffd2766, 0x0b11a9fa, 0x3fe33333, 0x3333333f},	/* 1.82212=f(0.6)*/
{62, 0,123,__LINE__, 0x3ffd7268, 0x31c4c762, 0x3fe3851e, 0xb851eb91},	/* 1.84043=f(0.61)*/
{63, 0,123,__LINE__, 0x3ffdbe2b, 0x54958ed3, 0x3fe3d70a, 0x3d70a3e3},	/* 1.85893=f(0.62)*/
{64, 0,123,__LINE__, 0x3ffe0ab1, 0x64090610, 0x3fe428f5, 0xc28f5c35},	/* 1.87761=f(0.63)*/
{64, 0,123,__LINE__, 0x3ffe57fc, 0x55a1aa65, 0x3fe47ae1, 0x47ae1487},	/* 1.89648=f(0.64)*/
{62, 0,123,__LINE__, 0x3ffea60e, 0x23ec475d, 0x3fe4cccc, 0xccccccd9},	/* 1.91554=f(0.65)*/
{64, 0,123,__LINE__, 0x3ffef4e8, 0xce8cee85, 0x3fe51eb8, 0x51eb852b},	/* 1.93479=f(0.66)*/
{63, 0,123,__LINE__, 0x3fff448e, 0x5a4c108a, 0x3fe570a3, 0xd70a3d7d},	/* 1.95424=f(0.67)*/
{64, 0,123,__LINE__, 0x3fff9500, 0xd123b808, 0x3fe5c28f, 0x5c28f5cf},	/* 1.97388=f(0.68)*/
{64, 0,123,__LINE__, 0x3fffe642, 0x424ce668, 0x3fe6147a, 0xe147ae21},	/* 1.99372=f(0.69)*/
{63, 0,123,__LINE__, 0x40001c2a, 0x6126898d, 0x3fe66666, 0x66666673},	/* 2.01375=f(0.7)*/
{63, 0,123,__LINE__, 0x4000459d, 0x3581e6c7, 0x3fe6b851, 0xeb851ec5},	/* 2.03399=f(0.71)*/
{64, 0,123,__LINE__, 0x40006f7a, 0xaddc411b, 0x3fe70a3d, 0x70a3d717},	/* 2.05443=f(0.72)*/
{64, 0,123,__LINE__, 0x400099c3, 0xdc943183, 0x3fe75c28, 0xf5c28f69},	/* 2.07508=f(0.73)*/
{64, 0,123,__LINE__, 0x4000c479, 0xd6ca39d7, 0x3fe7ae14, 0x7ae147bb},	/* 2.09594=f(0.74)*/
{64, 0,123,__LINE__, 0x4000ef9d, 0xb467dcff, 0x3fe80000, 0x0000000d},	/* 2.117=f(0.75)*/
{64, 0,123,__LINE__, 0x40011b30, 0x9026c963, 0x3fe851eb, 0x851eb85f},	/* 2.13828=f(0.76)*/
{63, 0,123,__LINE__, 0x40014733, 0x879815d5, 0x3fe8a3d7, 0x0a3d70b1},	/* 2.15977=f(0.77)*/
{62, 0,123,__LINE__, 0x400173a7, 0xbb2b9108, 0x3fe8f5c2, 0x8f5c2903},	/* 2.18147=f(0.78)*/
{63, 0,123,__LINE__, 0x4001a08e, 0x4e3723eb, 0x3fe947ae, 0x147ae155},	/* 2.2034=f(0.79)*/
{63, 0,123,__LINE__, 0x4001cde8, 0x66fe46f0, 0x3fe99999, 0x999999a7},	/* 2.22554=f(0.8)*/
{64, 0,123,__LINE__, 0x4001fbb7, 0x2eb98a93, 0x3fe9eb85, 0x1eb851f9},	/* 2.24791=f(0.81)*/
{64, 0,123,__LINE__, 0x400229fb, 0xd19e3339, 0x3fea3d70, 0xa3d70a4b},	/* 2.2705=f(0.82)*/
{64, 0,123,__LINE__, 0x400258b7, 0x7ee5e8a6, 0x3fea8f5c, 0x28f5c29d},	/* 2.29332=f(0.83)*/
{64, 0,123,__LINE__, 0x400287eb, 0x68d6793b, 0x3feae147, 0xae147aef},	/* 2.31637=f(0.84)*/
{64, 0,123,__LINE__, 0x4002b798, 0xc4c9b127, 0x3feb3333, 0x33333341},	/* 2.33965=f(0.85)*/
{64, 0,123,__LINE__, 0x4002e7c0, 0xcb3545cb, 0x3feb851e, 0xb851eb93},	/* 2.36316=f(0.86)*/
{63, 0,123,__LINE__, 0x40031864, 0xb7b2d577, 0x3febd70a, 0x3d70a3e5},	/* 2.38691=f(0.87)*/
{63, 0,123,__LINE__, 0x40034985, 0xc907fbc5, 0x3fec28f5, 0xc28f5c37},	/* 2.4109=f(0.88)*/
{64, 0,123,__LINE__, 0x40037b25, 0x412e7ab3, 0x3fec7ae1, 0x47ae1489},	/* 2.43513=f(0.89)*/
{63, 0,123,__LINE__, 0x4003ad44, 0x655c78c4, 0x3feccccc, 0xccccccdb},	/* 2.4596=f(0.9)*/
{63, 0,123,__LINE__, 0x4003dfe4, 0x7e0cd452, 0x3fed1eb8, 0x51eb852d},	/* 2.48432=f(0.91)*/
{63, 0,123,__LINE__, 0x40041306, 0xd7078c4b, 0x3fed70a3, 0xd70a3d7f},	/* 2.50929=f(0.92)*/
{63, 0,123,__LINE__, 0x400446ac, 0xbf6a3e95, 0x3fedc28f, 0x5c28f5d1},	/* 2.53451=f(0.93)*/
{64, 0,123,__LINE__, 0x40047ad7, 0x89b0bc48, 0x3fee147a, 0xe147ae23},	/* 2.55998=f(0.94)*/
{62, 0,123,__LINE__, 0x4004af88, 0x8bbdb3fa, 0x3fee6666, 0x66666675},	/* 2.58571=f(0.95)*/
{64, 0,123,__LINE__, 0x4004e4c1, 0x1ee3725d, 0x3feeb851, 0xeb851ec7},	/* 2.6117=f(0.96)*/
{62, 0,123,__LINE__, 0x40051a82, 0x9fecb95b, 0x3fef0a3d, 0x70a3d719},	/* 2.63794=f(0.97)*/
{63, 0,123,__LINE__, 0x400550ce, 0x6f25adef, 0x3fef5c28, 0xf5c28f6b},	/* 2.66446=f(0.98)*/
{64, 0,123,__LINE__, 0x400587a5, 0xf064dd04, 0x3fefae14, 0x7ae147bd},	/* 2.69123=f(0.99)*/
{62, 0,123,__LINE__, 0x4005bf0a, 0x8b145773, 0x3ff00000, 0x00000007},	/* 2.71828=f(1)*/
{64, 0,123,__LINE__, 0x4005f6fd, 0xaa3ae58a, 0x3ff028f5, 0xc28f5c30},	/* 2.7456=f(1.01)*/
{64, 0,123,__LINE__, 0x40062f80, 0xbc855229, 0x3ff051eb, 0x851eb859},	/* 2.77319=f(1.02)*/
{64, 0,123,__LINE__, 0x40066895, 0x344fcdd6, 0x3ff07ae1, 0x47ae1482},	/* 2.80107=f(1.03)*/
{64, 0,123,__LINE__, 0x4006a23c, 0x87af69f1, 0x3ff0a3d7, 0x0a3d70ab},	/* 2.82922=f(1.04)*/
{64, 0,123,__LINE__, 0x4006dc78, 0x307bac53, 0x3ff0cccc, 0xccccccd4},	/* 2.85765=f(1.05)*/
{64, 0,123,__LINE__, 0x40071749, 0xac583b88, 0x3ff0f5c2, 0x8f5c28fd},	/* 2.88637=f(1.06)*/
{64, 0,123,__LINE__, 0x400752b2, 0x7cbea3f3, 0x3ff11eb8, 0x51eb8526},	/* 2.91538=f(1.07)*/
{62, 0,123,__LINE__, 0x40078eb4, 0x27083615, 0x3ff147ae, 0x147ae14f},	/* 2.94468=f(1.08)*/
{64, 0,123,__LINE__, 0x4007cb50, 0x3477fe31, 0x3ff170a3, 0xd70a3d78},	/* 2.97427=f(1.09)*/
{63, 0,123,__LINE__, 0x40080888, 0x3244d59d, 0x3ff19999, 0x999999a1},	/* 3.00417=f(1.1)*/
{62, 0,123,__LINE__, 0x4008465d, 0xb1a38df6, 0x3ff1c28f, 0x5c28f5ca},	/* 3.03436=f(1.11)*/
{64, 0,123,__LINE__, 0x400884d2, 0x47d1367b, 0x3ff1eb85, 0x1eb851f3},	/* 3.06485=f(1.12)*/
{64, 0,123,__LINE__, 0x4008c3e7, 0x8e1d7bdc, 0x3ff2147a, 0xe147ae1c},	/* 3.09566=f(1.13)*/
{63, 0,123,__LINE__, 0x4009039f, 0x21f522b5, 0x3ff23d70, 0xa3d70a45},	/* 3.12677=f(1.14)*/
{63, 0,123,__LINE__, 0x400943fa, 0xa4ec9cfe, 0x3ff26666, 0x6666666e},	/* 3.15819=f(1.15)*/
{64, 0,123,__LINE__, 0x400984fb, 0xbccababa, 0x3ff28f5c, 0x28f5c297},	/* 3.18993=f(1.16)*/
{63, 0,123,__LINE__, 0x4009c6a4, 0x13937621, 0x3ff2b851, 0xeb851ec0},	/* 3.22199=f(1.17)*/
{63, 0,123,__LINE__, 0x400a08f5, 0x5792db9b, 0x3ff2e147, 0xae147ae9},	/* 3.25437=f(1.18)*/
{64, 0,123,__LINE__, 0x400a4bf1, 0x3b680dbf, 0x3ff30a3d, 0x70a3d712},	/* 3.28708=f(1.19)*/
{61, 0,123,__LINE__, 0x3f5e989f, 0x5d6dff5e, 0xc01921fb, 0x54442d18},	/* 0.00186744=f(-6.28319)*/
{63, 0,123,__LINE__, 0x3f8265d4, 0xe92b6b9c, 0xc012d97c, 0x7f3321d2},	/* 0.00898329=f(-4.71239)*/
{64, 0,123,__LINE__, 0x3fa62022, 0x7b598efa, 0xc00921fb, 0x54442d18},	/* 0.0432139=f(-3.14159)*/
{62, 0,123,__LINE__, 0x3fca9bcc, 0x46f767e0, 0xbff921fb, 0x54442d18},	/* 0.20788=f(-1.5708)*/
{64, 0,123,__LINE__, 0x3ff00000, 0x00000000, 0x00000000, 0x00000000},	/* 1=f(0)*/
{63, 0,123,__LINE__, 0x40133ded, 0xc855935f, 0x3ff921fb, 0x54442d18},	/* 4.81048=f(1.5708)*/
{63, 0,123,__LINE__, 0x40372404, 0x6eb09339, 0x400921fb, 0x54442d18},	/* 23.1407=f(3.14159)*/
{62, 0,123,__LINE__, 0x405bd456, 0x7b975380, 0x4012d97c, 0x7f3321d2},	/* 111.318=f(4.71239)*/
{60, 0,123,__LINE__, 0x3d3a56e0, 0xc2ac7f75, 0xc03e0000, 0x00000000},	/* 9.35762e-14=f(-30)*/
{60, 0,123,__LINE__, 0x3d6205c5, 0x18d0dcb5, 0xc03c4ccc, 0xcccccccd},	/* 5.12231e-13=f(-28.3)*/
{60, 0,123,__LINE__, 0x3d88a9e2, 0x293214dc, 0xc03a9999, 0x9999999a},	/* 2.80393e-12=f(-26.6)*/
{62, 0,123,__LINE__, 0x3db0e03b, 0xb495bb55, 0xc038e666, 0x66666667},	/* 1.53486e-11=f(-24.9)*/
{61, 0,123,__LINE__, 0x3dd7182e, 0xae519ae7, 0xc0373333, 0x33333334},	/* 8.40172e-11=f(-23.2)*/
{62, 0,123,__LINE__, 0x3dff9abe, 0x68b14e62, 0xc0358000, 0x00000001},	/* 4.59906e-10=f(-21.5)*/
{61, 0,123,__LINE__, 0x3e25a009, 0xc96ebd12, 0xc033cccc, 0xccccccce},	/* 2.5175e-09=f(-19.8)*/
{62, 0,123,__LINE__, 0x3e4d97fe, 0xd98fac4f, 0xc0321999, 0x9999999b},	/* 1.37807e-08=f(-18.1)*/
{61, 0,123,__LINE__, 0x3e743fd3, 0x3a226a26, 0xc0306666, 0x66666668},	/* 7.54346e-08=f(-16.4)*/
{62, 0,123,__LINE__, 0x3e9bb5ff, 0x19442358, 0xc02d6666, 0x6666666a},	/* 4.12925e-07=f(-14.7)*/
{61, 0,123,__LINE__, 0x3ec2f605, 0x3b981d72, 0xc02a0000, 0x00000004},	/* 2.26033e-06=f(-13)*/
{62, 0,123,__LINE__, 0x3ee9f2a9, 0xc30dbeac, 0xc0269999, 0x9999999e},	/* 1.23729e-05=f(-11.3)*/
{61, 0,123,__LINE__, 0x3f11c132, 0xd5399ed0, 0xc0233333, 0x33333338},	/* 6.77287e-05=f(-9.6)*/
{62, 0,123,__LINE__, 0x3f384c0b, 0x61a858e1, 0xc01f9999, 0x999999a3},	/* 0.000370744=f(-7.9)*/
{64, 0,123,__LINE__, 0x3f60a006, 0x46cbe754, 0xc018cccc, 0xccccccd6},	/* 0.00202943=f(-6.2)*/
{63, 0,123,__LINE__, 0x3f86c050, 0x4695c3e4, 0xc0120000, 0x00000009},	/* 0.011109=f(-4.5)*/
{62, 0,123,__LINE__, 0x3faf227f, 0x1c7c6d40, 0xc0066666, 0x66666678},	/* 0.0608101=f(-2.8)*/
{62, 0,123,__LINE__, 0x3fd54dc2, 0x84911bc2, 0xbff19999, 0x999999bd},	/* 0.332871=f(-1.1)*/
{64, 0,123,__LINE__, 0x3ffd2766, 0x0b11a9af, 0x3fe33333, 0x333332ec},	/* 1.82212=f(0.6)*/
{62, 0,123,__LINE__, 0x4023f2c8, 0x0aef8821, 0x40026666, 0x66666654},	/* 9.97418=f(2.3)*/
{63, 0,123,__LINE__, 0x404b4c90, 0x2e273a1b, 0x400fffff, 0xffffffee},	/* 54.5982=f(4)*/
{62, 0,123,__LINE__, 0x4072ade0, 0xdfd62085, 0x4016cccc, 0xccccccc4},	/* 298.867=f(5.7)*/
{64, 0,123,__LINE__, 0x40998ff0, 0x0e6ab69c, 0x401d9999, 0x99999991},	/* 1635.98=f(7.4)*/
{62, 0,123,__LINE__, 0x40c17da5, 0x774ec643, 0x40223333, 0x3333332f},	/* 8955.29=f(9.1)*/
{62, 0,123,__LINE__, 0x40e7ef99, 0xa2e8c3ad, 0x40259999, 0x99999995},	/* 49020.8=f(10.8)*/
{63, 0,123,__LINE__, 0x411060c5, 0x2565ba3d, 0x4028ffff, 0xfffffffb},	/* 268337=f(12.5)*/
{61, 0,123,__LINE__, 0x413669c0, 0x308d2b7b, 0x402c6666, 0x66666661},	/* 1.46886e+06=f(14.2)*/
{63, 0,123,__LINE__, 0x415eac09, 0x532f3e03, 0x402fcccc, 0xccccccc7},	/* 8.04049e+06=f(15.9)*/
{61, 0,123,__LINE__, 0x4184fcb4, 0x4c4756dc, 0x40319999, 0x99999997},	/* 4.40132e+07=f(17.6)*/
{61, 0,123,__LINE__, 0x41acb879, 0xa3e73665, 0x40334ccc, 0xccccccca},	/* 2.40926e+08=f(19.3)*/
{62, 0,123,__LINE__, 0x41d3a6e1, 0xfd9eecc2, 0x4034ffff, 0xfffffffd},	/* 1.31882e+09=f(21)*/
{60, 0,123,__LINE__, 0x41fae4b2, 0x68df16f2, 0x4036b333, 0x33333330},	/* 7.21913e+09=f(22.7)*/
{62, 0,123,__LINE__, 0x422266ce, 0xffa8459a, 0x40386666, 0x66666663},	/* 3.95171e+10=f(24.4)*/
{61, 0,123,__LINE__, 0x42492ead, 0xfa098707, 0x403a1999, 0x99999996},	/* 2.16315e+11=f(26.1)*/
{60, 0,123,__LINE__, 0x42713b19, 0x1e69fb1e, 0x403bcccc, 0xccccccc9},	/* 1.1841e+12=f(27.8)*/
{60, 0,123,__LINE__, 0x42979487, 0x9e85b8ea, 0x403d7fff, 0xfffffffc},	/* 6.48167e+12=f(29.5)*/
{0}
};
void test_exp(int m)   {run_vector_1(m,exp_vec,(char *)(exp),"exp","dd");   }	
